




"Data Structure Folder"
___

#  pFolder

## pFolder

Data Structure Folder






___

TBDF-Incoming Weekly Measurement Data
___

# Create Data Structure

## Data Structure

TBDF-Incoming Weekly Measurement Data

## Description
This describes the weekly measurement data for each patient for the Teddy Bear drop foot clinical trial

## In Data Specification
Data Specification for Teddy Bear Drop Foot Clinical Trial


## Qualified Name


___

WWT-Incoming Weekly Measurement Data
___

# Create Data Structure

## Data Structure

WWT-Incoming Weekly Measurement Data


##  Description
A collection of data fields that form a data structure.


##  In Data Specification



##  Qualified Name



# Create Data Structure

## Name

WWT-Incoming Weekly Measurement Data

## Description

This describes  the weekly measurement data for each patient for the Werewolf Transformation clinical trial

## In Data Spec

Data Specification for Werewolf Transformation Clinical Trial


___




"Data Specifications Folder"
___

#  pFolder

## pFolder

Data Specifications Folder






___

Data Specification for the Teddy Bear Drop Foot Clinical Trial
___

# Create Data Specification

## Data Specification

Data Specification for the Teddy Bear Drop Foot Clinical Trial

##  Description
Principle data requirements for this clinical trial.


##  Is Own Anchor
true


##  Parent Relationship Type



##  Parent at End1
false


##  Qualified Name







##  Anchor Scope Name




##  GUID



##  Anchor ID



##  Parent ID








___

Data Specification for the Werewolf Transformation Clinical Trial
___

# Create Data Specification

## Data Specification

Data Specification for the Werewolf Transformation Clinical Trial

##  Description
A collection of data fields that for a data specification for a data source.


##  Is Own Anchor
true


##  Parent Relationship Type



##  Parent at End1
false


##  Qualified Name







##  Anchor Scope Name




##  GUID



##  Anchor ID



##  Parent ID



# Create Data Spec

## Data Spec

Data Specification for the Werewolf Transformation Clinical Trial

## Description

Data collection requirements for the Werewolf Transformation Clinical Trial



___




"Data Dictionary Folder"
___

#  pFolder

## pFolder

Data Dictionary Folder






___

Clinical Trials Data Dictionary
___

# Create Data Dictionary

## Data Dictionary

Clinical Trials Data Dictionary

##  Description
A collection of data fields that for a data specification for a data source.


##  Is Own Anchor
false


##  Parent Relationship Type



##  Anchor Scope Name



##  Parent at End1
false


##  Qualified Name








##  GUID



##  Anchor ID



##  Parent ID

___




"Data Class Folder"
___

#  pFolder

## pFolder

Data Class Folder






___

Angle-Class
___

# Create Data Class

## Data Class

Angle-Class


##  Description
Classification criteria for data fields


##  Namespace



##  Match Property Names



##  Match Threshold
0


##  IsCaseSensitive
false


##  Specification



##  Specification Details



##  Data Type



##  Allow Duplicate Values
false


##  IsNullable
false


##  Default Value



##  Average Value
0


##  Value List



##  Value Range From
0


##  Value Range To:
	



##  Sample Values



##  Data Patterns



##  Name Patterns



##  In Data Dictionary



##  Qualified Name






##  GUID





# Create Data Class
## Name
Angle-Class
## Description
An integer representing the measurement of an angle.

## namespace

## matchPropertyNames - Dr.E  can set - name of the properties that are set

## matchThreshold - % of values that match the data class specification


## specification - rules language - skip?

## specification details - values for a rule - skip?

## data type
Integer

## allowsDuplicateValues - boolean
true
## isNullable
false
## defaultValue

## average value

## valueList

## valueRangeFrom
0
## valueRangeTo
359
## sample values

## dataPatterns

## namePatterns

## In Data Dictionary
Clinical Trials Data Dictionary







___

Minutes - Class
___

# Create Data Class

## Data Class

Minutes - Class


##  Description
Classification criteria for data fields


##  Namespace



##  Match Property Names



##  Match Threshold
0


##  IsCaseSensitive
false


##  Specification



##  Specification Details



##  Data Type



##  Allow Duplicate Values
false


##  IsNullable
false


##  Default Value



##  Average Value
0


##  Value List



##  Value Range From
0


##  Value Range To:
	versionId: Version Identifier
0


##  Sample Values



##  Data Patterns



##  Name Patterns



##  In Data Dictionary



##  Qualified Name






##  GUID





# Create Data Class
## Name
Minutes-Class
## Description
A number representing time in minutes.

## namespace

## matchPropertyNames - Dr.E  can set - name of the properties that are set

## matchThreshold - % of values that match the data class specification


## specification - rules language - skip?

## specification details - values for a rule - skip?

## data type
Integer
## allowsDuplicateValues - boolean
True
## isNullable

## defaultValue

## average value

## valueList

## valueRangeFrom
0
## valueRangeTo

## sample values

## dataPatterns

## namePatterns

## In Data Dictionary
Clinical Trials Data Dictionary







___

Percent - Class
___

# Create Data Class

## Data Class

Percent - Class


##  Description
Classification criteria for data fields


##  Namespace



##  Match Property Names



##  Match Threshold
0


##  IsCaseSensitive
false


##  Specification



##  Specification Details



##  Data Type



##  Allow Duplicate Values
false


##  IsNullable
false


##  Default Value



##  Average Value
0


##  Value List



##  Value Range From
0


##  Value Range To:
	versionId: Version Identifier
0


##  Sample Values



##  Data Patterns



##  Name Patterns



##  In Data Dictionary



##  Qualified Name






##  GUID





# Create Data Class
## Name
Percent-Class
## Description
An integer representing a percentage.

## namespace

## matchPropertyNames - Dr.E  can set - name of the properties that are set

## matchThreshold - % of values that match the data class specification


## specification - rules language - skip?

## specification details - values for a rule - skip?

## data type
Integer
## allowsDuplicateValues - boolean
True

## isNullable

## defaultValue

## average value

## valueList

## valueRangeFrom
0
## valueRangeTo
100
## sample values

## dataPatterns

## namePatterns

## In Data Dictionary
Clinical Trials Data Dictionary






___

Date-Class
___

# Create Data Class

## Data Class

Date-Class


##  Description
Classification criteria for data fields


##  Namespace



##  Match Property Names



##  Match Threshold
0


##  IsCaseSensitive
false


##  Specification



##  Specification Details



##  Data Type



##  Allow Duplicate Values
false


##  IsNullable
false


##  Default Value



##  Average Value
0


##  Value List



##  Value Range From
0


##  Value Range To:
	versionId: Version Identifier
0


##  Sample Values



##  Data Patterns



##  Name Patterns



##  In Data Dictionary
Clinical Trials Data Dictionary


##  Qualified Name






##  GUID





# Create Data Class
## Name
Date-Class

## Description
A field of type date

## namespace

## data type
Date

## allowsDuplicateValues - boolean
True

## isNullable

## defaultValue

## average value

## valueList

## valueRangeFrom

## valueRangeTo

## sample values

## dataPatterns

## namePatterns

## In Data Dictionary
Clinical Trials Data Dictionary





___

patientId-Class
___

# Create Data Class

## Data Class

patientId-Class


##  Description
Classification criteria for data fields


##  Namespace



##  Match Property Names



##  Match Threshold
0


##  IsCaseSensitive
false


##  Specification



##  Specification Details



##  Data Type



##  Allow Duplicate Values
false


##  IsNullable
false


##  Default Value



##  Average Value
0


##  Value List



##  Value Range From
0


##  Value Range To:
	versionId: Version Identifier
0


##  Sample Values



##  Data Patterns



##  Name Patterns



##  In Data Dictionary



##  Qualified Name






##  GUID










___

date-Class
___

# Create Data Class

## Data Class

date-Class


##  Description
Classification criteria for data fields


##  Namespace



##  Match Property Names



##  Match Threshold
0


##  IsCaseSensitive
false


##  Specification



##  Specification Details



##  Data Type



##  Allow Duplicate Values
false


##  IsNullable
false


##  Default Value



##  Average Value
0


##  Value List



##  Value Range From
0


##  Value Range To:
	versionId: Version Identifier
0


##  Sample Values



##  Data Patterns



##  Name Patterns



##  In Data Dictionary



##  Qualified Name






##  GUID










___

Measurement-Date-Class
___

# Create Data Class

## Data Class

Measurement-Date-Class


##  Description
Classification criteria for data fields


##  Namespace



##  Match Property Names



##  Match Threshold
0


##  IsCaseSensitive
false


##  Specification



##  Specification Details



##  Data Type



##  Allow Duplicate Values
false


##  IsNullable
false


##  Default Value



##  Average Value
0


##  Value List



##  Value Range From
0


##  Value Range To:
	versionId: Version Identifier
0


##  Sample Values



##  Data Patterns



##  Name Patterns



##  In Data Dictionary



##  Qualified Name






##  GUID


___





"Data Fields Folder"
___

#  pFolder

## pFolder

Data Fields Folder






___

PatientId
___

# Create Data Field

## Data Field

PatientId


##  Description
The unique identifier for a patient.


##  Data Type
String


##  Position
0


##  Parent Data Field



##  Minimum Cardinality




##  In Data Structure
TBDF-Incoming Weekly Measurement Data;WWT-Incoming Weekly Measurement Data



##  Glossary Term
GlossaryTerm::PatientID


##  In Data Dictionary
Clinical Trials Data Dictionary


##  Aliases



##  Name Patterns



##  IsNullable
false



##  Length
0


##  Precision



##  Ordered Values
false


##  Units



##  Sort Order



##  Default Value



## Additional Properties




##  Namespace



##  Qualified Name
DataField::PatientId




# Create Data Field

## Data Field

PatientId

##  Description
The unique identifier for a patient.


##  Data Type
String


##  Position
0


##  Parent Data Field



##  Minimum Cardinality



##  In Data Structure
TBDF-Incoming Weekly Measurement Data;WWT-Incoming Weekly Measurement Data


##  Glossary Term
GlossaryTerm::PatientID


##  In Data Dictionary
Clinical Trials Data Dictionary


##  Aliases



##  Name Patterns



##  IsNullable
false


##  Length
0


##  Precision



##  Ordered Values
false


##  Units



##  Sort Order



##  Default Value



## Additional Properties



##  Namespace



##  Qualified Name
DataField::PatientId






___

Zip Code
___

# Create Data Field

## Data Field

Zip Code


##  Description
A zip code is a US Postal Code


##  Data Type
String


##  Position
0


##  Parent Data Field
Postal Code


##  Minimum Cardinality




##  In Data Structure




##  Glossary Term



##  In Data Dictionary



##  Aliases



##  Name Patterns



##  IsNullable
false



##  Length
0


##  Precision



##  Ordered Values
false


##  Units



##  Sort Order



##  Default Value



## Additional Properties




##  Namespace



##  Qualified Name












___

Postal Code
___

# Create Data Field

## Data Field

Postal Code


##  Description
A collection of data fields that for a data specification for a data source.


##  Data Type



##  Position
0


##  Parent Data Field
Address


##  Minimum Cardinality




##  In Data Structure
Address;TBDF-Incoming Weekly Measurement Data



##  Glossary Term



##  In Data Dictionary



##  Aliases



##  Name Patterns



##  IsNullable
false



##  Length
0


##  Precision



##  Ordered Values
false


##  Units



##  Sort Order



##  Default Value



## Additional Properties




##  Namespace



##  Qualified Name










___

Address
___

# Create Data Field

## Data Field

Address


##  Description
A collection of data fields that for a data specification for a data source.


##  Data Type



##  Position
0


##  Parent Data Field



##  Minimum Cardinality




##  In Data Structure




##  Glossary Term



##  In Data Dictionary



##  Aliases



##  Name Patterns



##  IsNullable
false



##  Length
0


##  Precision



##  Ordered Values
false


##  Units



##  Sort Order



##  Default Value



## Additional Properties




##  Namespace



##  Qualified Name










___

Date
___

# Create Data Field

## Data Field

Date


##  Description
A collection of data fields that for a data specification for a data source.


##  Data Type
Date


##  Position
0


##  Parent Data Field



##  Minimum Cardinality




##  In Data Structure
TBDF-Incoming Weekly Measurement Data;WWT-Incoming Weekly Measurement Data



##  Glossary Term



##  In Data Dictionary
Clinical Trials Data Dictionary


##  Aliases



##  Name Patterns



##  IsNullable
false



##  Length
0


##  Precision



##  Ordered Values
false


##  Units



##  Sort Order



##  Default Value



## Additional Properties




##  Namespace



##  Qualified Name










___

AngleLeft
___

# Create Data Field

## Data Field

AngleLeft


##  Description
Angle rotation of the left leg from vertical


##  Data Type
Integer


##  Position
0


##  Parent Data Field



##  Minimum Cardinality




##  In Data Structure
TBDF-Incoming Weekly Measurement Data



##  Glossary Term
Leg Angle Measurement


##  In Data Dictionary
Clinical Trials Data Dictionary


##  Aliases



##  Name Patterns



##  IsNullable
false



##  Length
0


##  Precision



##  Ordered Values
false


##  Units



##  Sort Order



##  Default Value



## Additional Properties




##  Namespace



##  Qualified Name










___

AngleRight
___

# Create Data Field

## Data Field

AngleRight


##  Description
Angle rotation of the left leg from vertical



##  Data Type
Integer


##  Position
0


##  Parent Data Field



##  Minimum Cardinality




##  In Data Structure
TBDF-Incoming Weekly Measurement Data



##  Glossary Term



##  In Data Dictionary
Clinical Trials Data Dictionary


##  Aliases



##  Name Patterns



##  IsNullable
false



##  Length
0


##  Precision



##  Ordered Values
false


##  Units



##  Sort Order



##  Default Value



## Additional Properties




##  Namespace



##  Qualified Name










___

Transformation Completeness
___

# Create Data Field

## Data Field

Transformation Completeness


##  Description
Percent completeness of the werewolf transformation


##  Data Type
Integer


##  Position
0


##  Parent Data Field



##  Minimum Cardinality




##  In Data Structure
TBDF-Incoming Weekly Measurement Data



##  Glossary Term



##  In Data Dictionary
Clinical Trials Data Dictionary


##  Aliases



##  Name Patterns



##  IsNullable
false



##  Length
0


##  Precision



##  Ordered Values
false


##  Units
percent


##  Sort Order



##  Default Value



## Additional Properties




##  Namespace



##  Qualified Name










___

Transformation Speed
___

# Create Data Field

## Data Field

Transformation Speed


##  Description
Speed of the werewolf transformation in minutes.



##  Data Type
Integer


##  Position
0


##  Parent Data Field



##  Minimum Cardinality




##  In Data Structure
TBDF-Incoming Weekly Measurement Data



##  Glossary Term



##  In Data Dictionary
Clinical Trials Data Dictionary


##  Aliases



##  Name Patterns



##  IsNullable
false



##  Length
0


##  Precision



##  Ordered Values
false


##  Units
minutes


##  Sort Order



##  Default Value



## Additional Properties




##  Namespace



##  Qualified Name










___

Transformation Duration
___

# Create Data Field

## Data Field

Transformation Duration


##  Description
Duration of the werewolf transformation, in minutes.


##  Data Type
Integer


##  Position
0


##  Parent Data Field



##  Minimum Cardinality




##  In Data Structure
WWT-Incoming Weekly Measurement Data



##  Glossary Term



##  In Data Dictionary
Clinical Trials Data Dictionary


##  Aliases



##  Name Patterns



##  IsNullable
false



##  Length
0


##  Precision



##  Ordered Values
false


##  Units
Minutes


##  Sort Order



##  Default Value



## Additional Properties




##  Namespace



##  Qualified Name























___


# Create Data Field
## Name
Patient Country
## Description
Country of the patient
## Data Type
String
## Position
0
## Min Cardinality
1
## Max Cardinality
1

## In Data Structure


## Data Class
## Glossary Term

## Namespace
> forms part of qualified name

## Version

## Parent
DataField::PatientId
## In Data Dictionary

## Qualified Name








